<?

/* 
Function Name: Time Since 
Function URI: http://binarybonsai.com/wordpress/timesince
Description: Tells the time between the entry being posted and the comment being made.
Author: Michael Heilemann & Dunstan Orchard
Author URI: http://binarybonsai.com
*/
function time_since($older_date, $newer_date = false)
{
	// array of time period chunks
	$chunks = array(
	array(60 * 60 * 24 * 365 , 'year'),
	array(60 * 60 * 24 * 30 , 'month'),
	array(60 * 60 * 24 * 7, 'week'),
	array(60 * 60 * 24 , 'day'),
	array(60 * 60 , 'hour'),
	array(60 , 'minute'),
	);
	
	// $newer_date will equal false if we want to know the time elapsed between a date and the current time
	// $newer_date will have a value if we want to work out time elapsed between two known dates
	$newer_date = ($newer_date == false) ? (time()+(60*60*get_settings("gmt_offset"))) : $newer_date;
	
	// difference in seconds
	$since = $newer_date - $older_date;
	
	// we only want to output two chunks of time here, eg:
	// x years, xx months
	// x days, xx hours
	// so there's only two bits of calculation below:

	// step one: the first chunk
	for ($i = 0, $j = count($chunks); $i < $j; $i++)
		{
		$seconds = $chunks[$i][0];
		$name = $chunks[$i][1];

		// finding the biggest chunk (if the chunk fits, break)
		if (($count = floor($since / $seconds)) != 0)
			{
			break;
			}
		}

	// set output var
	$output = ($count == 1) ? '1 '.$name : "$count {$name}s";

	// step two: the second chunk
	if ($i + 1 < $j)
		{
		$seconds2 = $chunks[$i + 1][0];
		$name2 = $chunks[$i + 1][1];
		
		if (($count2 = floor(($since - ($seconds * $count)) / $seconds2)) != 0)
			{
			// add to output var
			$output .= ($count2 == 1) ? ', 1 '.$name2 : ", $count2 {$name2}s";
			}
		}
	
	return $output;
}

// Get the date of the last comment for a particular post.
function last_comment_date($post_id) {
	global $wpdb;
	
	$date = $wpdb->get_results("
		SELECT comment_date_gmt FROM `$wpdb->comments`
		WHERE comment_post_id = $post_id
		ORDER BY comment_date_gmt DESC
		LIMIT 1", ARRAY_N);

	return $date[0][0];
}


// Altered from original by Dougal, to enable seperation of categories.
// Fixes contributed by Douglas.
// Mashed up for Wordpress 2.1

function get_grouped_links_list($order = 'name', $hide_if_empty = 'obsolete') {
	global $wpdb, $wp_version;

	$order = strtolower($order);

	// Handle link category sorting
	if (substr($order,0,1) == '_') {
		$direction = ' DESC';
		$order = substr($order,1);
	}

	// if 'name' wasn't specified, assume 'id':
	$cat_order = ('name' == $order) ? 'cat_name' : 'cat_id';

	if (!isset($direction)) $direction = '';
	// Fetch the link category data as an array of hashesa

    if($wp_version >= 2.1) {                                                
            // Returns all link categories with 1 or more links             
            $cats = get_categories("type=link&hierarchical=0");             
    }
	else {
		$cats = $wpdb->get_results("
			SELECT DISTINCT link_category, cat_name, show_images, 
				show_description, show_rating, show_updated, sort_order, 
				sort_desc, list_limit
			FROM `$wpdb->links` 
			LEFT JOIN `$wpdb->linkcategories` ON (link_category = cat_id)
			WHERE link_visible =  'Y'
				AND list_limit <> 0
			ORDER BY $cat_order $direction ", ARRAY_A);
	}
	
	//var_dump($cats);
	
	// Actually I'm gonna hack it here, and get categories ordered by number of links.
	// It's just easier for the layout that way. My bad.
	
	if( count($cats) < 1) { return false; }
	
	foreach ($cats as $cat) 
	{ 
		if($wp_version >= 2.1) {
			//var_dump($cat);
			$num_links[$cat->link_category] = $cat->link_count;
		}
		else {
			$num_links[$cat['link_category']] = $wpdb->get_results("SELECT count(*) FROM `$wpdb->links` WHERE link_category = " . $cat['link_category'], ARRAY_A);
		}
	}
	
	arsort($num_links);

	foreach ($num_links as $key => $value)
	{
		for($i=0;$i<count($cats);$i++)
		{
			if($wp_version < 2.1) 
			{	
				if($cats[$i]["link_category"] == $key)
				{
					$new_cats[] = $cats[$i];
				}
			}
			else {
				if($cats[$i]->link_category == $key)
				{
					$new_cats[] = $cats[$i];
				}				
			}
		}
	}
	
	// End the dirty, dirty hack.
	
	// Display each category
	if ($new_cats) {
		foreach ($new_cats as $cat) {
			// Handle each category.
			// First, fix the sort_order info

			// Display the category name
			if($wp_version < 2.1) {
				echo '	<div class="column" id="linkcat-' . $cat['link_category'] . '"><h3>' . $cat['cat_name'] . "</h3>\n\t<ul>\n";
			}
			else {
				echo '	<div class="column" id="linkcat-' . $cat->link_category . '"><h3>' . $cat->cat_name . "</h3>\n\t<ul>\n";				
			}
			// Call get_links() with all the appropriate params
			
			
			if($wp_version < 2.1) {
				$orderby = $cat['sort_order'];
				$orderby = (bool_from_yn($cat['sort_desc'])?'_':'') . $orderby;
							
				get_links($cat['link_category'],
					'<li>',"</li>","\n",
					bool_from_yn($cat['show_images']),
					$orderby,
					bool_from_yn($cat['show_description']),
					bool_from_yn($cat['show_rating']),
					$cat['list_limit'],
					bool_from_yn($cat['show_updated']));
			}
			else {
				get_links($cat->link_category, '<li>',"</li>", "\n");
			}
			
			// Close the last category
			echo "\n\t</ul>\n</div>\n";
		}
	}
}

// Checks to see if there any pages.
function check_num_pages() {

	// Query pages.
	$pages = & get_pages($args);
	if ( !$pages ) {
		return false;
	}
	
	return true;
}



include(dirname(__FILE__).'/themetoolkit.php');

themetoolkit(
	'durable',
	array(
	'pagestyle' => 'Page Style {radio|ripped|Page Rip Effect|solid|Solid Colors}',
	'posts_pp' => 'Number of Posts on Front Page {radio|3|3 Posts|5|5 Posts|7|7 Posts|9|9 Posts}',
	'alignment' => 'Posts Should Be: {radio|left|Left Aligned|justify|Justified}',
	'colorchange' => 'Let Users Change Colors? {radio|true|Yes|false|No}',
	'showlogin' => 'Show Login/Admin link in menu? {radio|true|Yes|false|No}',
	'floatimages_left' => 'Position images to the left in articles and force text to wrap around? {radio|true|Yes|false|No}',
	),
	__FILE__	 
);

/*
 *	Set up the default theme colors on installation.
 */

if (!$durable->is_installed()) 
{
	saveColors('default');
}

function saveColors($mode)
{
	global $durable;
	global $user_level;
	// Check admin status..
	
	if($user_level > 8 || !$durable->is_installed())
	{
		// Header Colors
		$set_defaults['header_bgclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['#header'], "#ff5c00", "backgroundColor");
		$set_defaults['header_txtclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['h1_a'], "#fff");
	
		// Menu Links
		$set_defaults['menulinks_lnktxtclr']=($mode=="default")?"#666":explodeCookie($_COOKIE['#topmenu_a'], "#666");
		$set_defaults['menulinks_lnkhvrclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['#topmenu_a:hover'], "#fff");
		$set_defaults['menulinks_lnkhvrbgclr']=($mode=="default")?"#3fbcec":explodeCookie($_COOKIE['#topmenu_a:hover'], "#3fbcec", "backgroundColor");	

		// Menu Sections
		$set_defaults['menusections_bgclr']=($mode=="default")?"#3fbcec":explodeCookie($_COOKIE['_menusection'], "#3fbcec", "backgroundColor");
		$set_defaults['menusections_txtclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['_menusection'], "#fff");
		$set_defaults['menusections_hdgclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['_menusection_h2'], "#fff");
		$set_defaults['menusections_lnktxtclr']=($mode=="default")?"#ffea00":explodeCookie($_COOKIE['_menusection_a'], "#ffea00");
		$set_defaults['menusections_lnkhvrclr']=($mode=="default")?"#3fbcec":explodeCookie($_COOKIE['_menusection_a:hover'], "#3fbcec");
		$set_defaults['menusections_lnkhvrbgclr']=($mode=="default")?"#ffea00":explodeCookie($_COOKIE['_menusection_a:hover'], "#ffea00", "backgroundColor");	

		// Main Content
		$set_defaults['maincontent_bgclr']=($mode=="default")?"#F5F5F5":explodeCookie($_COOKIE['#maincontent'], "#F5F5F5", "backgroundColor");
		$set_defaults['maincontent_txtclr']=($mode=="default")?"#666":explodeCookie($_COOKIE['#maincontent'], "#666");
		$set_defaults['maincontent_hdgclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['h2'], "#ff5c00");
		$set_defaults['maincontent_lnktxtclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['#maincontent_a'], "#ff5c00");
		$set_defaults['maincontent_lnkhvrclr']=($mode=="default")?"#F5F5F5":explodeCookie($_COOKIE['#maincontent_a:hover'], "#F5F5F5");
		$set_defaults['maincontent_lnkhvrbgclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['#maincontent_a:hover'], "#ff5c00", "backgroundColor");	

		// Dates & Tags
		$set_defaults['datestags_bgclr']=($mode=="default")?"#3fbcec":explodeCookie($_COOKIE['_categories_a'], "#3fbcec", "backgroundColor");
		$set_defaults['datestags_txtclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['_categories_a'], "#fff");
		$set_defaults['datestags_lnkhvrtxtclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['_categories_a:hover'], "#fff");
		$set_defaults['datestags_lnkhvrbgclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['_categories_a:hover'], "#ff5c00", "backgroundColor");

		// Comments
		$set_defaults['comments_rplyfrmbgclr']=($mode=="default")?"#ddd":explodeCookie($_COOKIE['#commentform'], "#ddd", "backgroundColor");
		$set_defaults['comments_rplyfrmhdgtxtclr']=($mode=="default")?"#666":explodeCookie($_COOKIE['#commentform_h2'], "#666");
		$set_defaults['comments_rplyfrmtxtclr']=($mode=="default")?"#666":explodeCookie($_COOKIE['#commentform'], "#666");
		$set_defaults['comments_rplybgclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['_alt'], "#fff", "backgroundColor");
		$set_defaults['comments_rplytxtclr']=($mode=="default")?"#666":explodeCookie($_COOKIE['_alt'], "#666");
		$set_defaults['comments_rplylnktxtclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['_alt_a'], "#ff5c00");	
		$set_defaults['comments_rplylnkhvrtxtclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['_alt_a:hover'], "#fff");	
		$set_defaults['comments_rplylnkhvrbgclr']=($mode=="default")?"#ff5c00":explodeCookie($_COOKIE['_alt_a:hover'], "#ff5c00", "backgroundColor");	
				
		// Footer Overview
	  	$set_defaults['footer_bgclr']=($mode=="default")?"#3fbcec":explodeCookie($_COOKIE['#overview'], "#3fbcec", "backgroundColor");	
	  	$set_defaults['footer_txtclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['#overview'], "#fff");
	  	$set_defaults['footer_hdgclr']=($mode=="default")?"#fff":explodeCookie($_COOKIE['#overview_h2'], "#fff");
	  	$set_defaults['footer_lnktxtclr']=($mode=="default")?"#ffea00":explodeCookie($_COOKIE['#overview_a'], "#ffea00");
	  	$set_defaults['footer_lnkhvrtxtclr']=($mode=="default")?"#3fbcec":explodeCookie($_COOKIE['#overview_a:hover'], "#3fbcec");
	  	$set_defaults['footer_lnkhvrbgclr']=($mode=="default")?"#ffea00":explodeCookie($_COOKIE['#overview_a:hover'], "#ffea00", "backgroundColor");

		// Pass other theme variables.
		$set_defaults['pagestyle']=($mode=="default")?"ripped":$durable->option['pagestyle'];
		$set_defaults['posts_pp']=($mode=="default")?"5":$durable->option['posts_pp'];
		$set_defaults['alignment']=($mode=="default")?"left":$durable->option['alignment'];
		$set_defaults['colorchange']=($mode=="default")?"true":$durable->option['colorchange'];
		$set_defaults['showlogin']=($mode=="default")?"true":$durable->option['showlogin'];
		$set_defaults['floatimages_left']=($mode=="default")?"false":$durable->option['floatimages_left'];
		
		
	  $result = $durable->store_options($set_defaults);
	}
}

function explodeCookie($cookieValue, $default, $attribute = "color")
{
	if($cookieValue == "")
	{
		return $default;
	}
	
	$cookieValue = str_replace(",", "", $cookieValue);
	$cookieValue = explode("|", $cookieValue);
	
	foreach($cookieValue as $key => $value)
	{
		if($value == $attribute)
		{
			return $cookieValue[$key+1];
		}
	}
}

/*
Plugin Name: Category Cloud + Monthly Cloud by Andy Peatling
Plugin URI: http://zak.greant.com/
Description: Template tag to display a categories in a tag cloud
Version: 0.1.1
Author: Zak Greant
Modified for Durable by: Andy Peatling
Author URI: http://zak.greant.com
*/

/*
New BSD License (http://www.opensource.org/licenses/bsd-license.php)
Category Cloud, Copyright (c) 2006, Foo Associates Inc.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
 * Neither the name of Foo Associates Inc. nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*
Thanks to Matt Kingston (http://www.hitormiss.org/).
Matt wrote a plugin called Weighted Categories that I stole ideas from.
*/

function mk_step($min, $max, $counts){
  return ($max - $min) / (max($counts) - min($counts) + 1);
}

function mk_stepped_base($base, $step, $count){
  return $base + $step * $count;
}

function monthly_cloud(
	$font_min          = 9, /* Minimum font size */
	$font_max          = 18, /* Maximum font size */
	$font_unit         = 'px' /* Font unit */
) {
	
	global $wpdb;
	global $month;
	
	$arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, count(ID) as posts FROM $wpdb->posts WHERE post_date < NOW() AND post_date != '0000-00-00 00:00:00' AND post_status = 'publish' GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date DESC");

	if ( $arcresults ) {
		$afterafter = $after;
		foreach ( $arcresults as $arcresult ) {
			
			$months[] = array("url" => get_month_link($arcresult->year,	$arcresult->month),
							  "name" => $month[zeroise($arcresult->month,2)] . ' ' . $arcresult->year,
							  "posts" => $arcresult->posts);

			$counts[$arcresult->posts] = 1;
		}
	}
	
	if(count($counts) == 1) { $count[0] = 1; }
	
  	sort($counts = array_keys($counts));
  	$step = mk_step($font_min, $font_max, $counts);
	
	for($i=0;$i<count($months);$i++) {

		if(count($arcresults) == 1) {
			echo '<span style="display: block; float: left; margin: 8px; font-size: 16px;">' . get_archives_link($months[$i]['url'], $months[$i]['name'], $format, $before, $after) . '</span>';
		}
		else {
			echo '<span style="display: block; float: left; margin: 8px; font-size: ' . mk_stepped_base($font_min, $step, $months[$i]['posts']) . $font_unit . ';">' . get_archives_link($months[$i]['url'], $months[$i]['name'], $format, $before, $after) . '</span>';
		}
	}
}

/*
Plugin Name: Category Cloud Widget (Modified for bundled use)
Plugin URI: http://leekelleher.com/wordpress/plugins/category-cloud-widget/
Description: Adds a sidebar widget to display the categories as a tag cloud.
Author: Lee Kelleher
Version: 1.1.1
Author URI: http://leekelleher.com/
*/
function category_cloud($limit = 9999999) {
	$defaults = array('small' => 10, 'big' => 20, 'unit' => 'px', 'align' => 'justify', 'hide-empty' => 1);
	foreach ( $defaults as $key => $value )
		if ( !isset($options[$key]) )
			$options[$key] = $defaults[$key];

	// omit title if not specified
	if ($options['title'] != '')
		echo $before_title . $options['title'] . $after_title;
	
	if ($options['exclude'] != '')
		$exclude = '&exclude=' . $options['exclude'];
	
	$hide_empty = '&hide_empty=' . $options['hide-empty'];
	
	
	// check which version of wp is being used
	if ( function_exists('get_categories') ) {
		
		// new version of wp (2.1+)
		$cats = get_categories("style=cloud&show_count=1&use_desc_for_title=0$exclude&hierarchical=0$hide_empty");
		
		$counter = 0;
		foreach ($cats as $cat) {
			if($counter <= $limit) {
				$catlink = get_category_link( $cat->cat_ID );
				$catname = $cat->cat_name;
				$count = $cat->category_count;
				$counts{$catname} = $count;
				$catlinks{$catname} = $catlink;
			}
			$counter++;
		}
		
	} else {
		
		// old version of wp (pre-2.1)
		$cats = wp_list_cats("list=0&sort_column=name&optioncount=1&use_desc_for_title=0$exclude&recurse=1&hierarchical=0$hide_empty");
		
		$cats = explode("<br />\n", $cats);
		$counter = 0;
		foreach ($cats as $cat) {
			if($counter <= $limit) {
				$regs = array(); // initialise the regs array
				eregi("a href=\"(.+)\" ", $cat, $regs);
				$catlink = $regs[1];
				$cat = trim(strip_tags($cat));
				eregi("(.*) \(([0-9]+)\)$", $cat, $regs);
				$catname = $regs[1];
				$count = $regs[2];
				$counts{$catname} = $count;
				$catlinks{$catname} = $catlink;
			}
			$counter++;
		}
	}
	
	$spread = max($counts) - min($counts); 
	if ($spread <= 0) { $spread = 1; };
	$fontspread = $options['big'] - $options['small'];
	$fontstep = $spread / $fontspread;
	if ($fontspread <= 0) { $fontspread = 1; }
	
	echo '<p class="catcloud" style="text-align:'.$options['align'].';">';
	
	foreach ($counts as $catname => $count)
	{
		$catlink = $catlinks{$catname};
		echo "\n<a href=\"$catlink\" title=\"$count entries\" style=\"font-size:".
			($options['small'] + ceil($count/$fontstep)).$options['unit']."\">$catname</a> ";
	}
	
	echo '</p>';
}

?>
